const gulp = require("gulp");
const pipe = require('gulp-pipe');
const through = require('through2');
const path = require('path');

const builder = require('nuance-gulp-build');

function exceptionHandler(ex) {
    console.error(ex);
}

function parseBool(v) {
    return (v || "false").toString().toLowerCase() == "true";
}

var configuration = null;

if (process.env["build_env"] == "debug_local") {
    configuration = builder.environments["file"](require('./buildinfo.json'))();
}
else {
    console.log(`using ${process.env["build_env"]} as environment`);
    configuration = builder.environments[process.env["build_env"]]();
}

const projects = function () {
    return gulp.src('./.buildconfig.json').pipe(through.obj(function (item, enc, done) {
        json = require(item.path);
        for (k in json.buildProjects) {
            var p = json.buildProjects[k];

            // this would change for bitbucket/gitlab
            p.configuration = configuration;

            if (parseBool(p.build)) {
                p.project = k;
                p.source_folder = path.dirname(p.source_path);
                p.file = path.resolve(p.source_path);
                p.source_path = p.file;
                this.push(p);
            }
        }
        done();
    }))
};

gulp.task("bump", () => projects(true).pipe(builder.bump()));

gulp.task('build', () => projects(true).pipe(builder.build()));

gulp.task('pack', () => projects(true).pipe(builder.pack()));

gulp.task('push', () => projects(true).pipe(builder.push()));

gulp.task('version', async () => await builder.version(configuration, 'VERSION.txt').catch(exceptionHandler));